Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSDOSRP.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSDOSRP.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSDOSRP.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSDOSRP ;BIR/RTR-Dosage review report ;03/24/00
+PSSDOSRP ;BIR/RTR-Dosage review report ; 8/16/05 3:44pm
  ;;1.0;PHARMACY DATA MANAGEMENT;**34,38,49**;9/30/97
  ;Reference to ^PS(50.607 supported by DBIA 2221
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSHLU.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSHLU.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSHLU.m	(revision 636)
@@ -1,4 +1,4 @@
 PSSHLU ;BIR/RLW-UTILITIES USED IN BUILDING HL7 SEGMENTS ;11/14/96
- ;;1.0;PHARMACY DATA MANAGEMENT;**38,124,132**;9/30/97;Build 1
+ ;;1.0;PHARMACY DATA MANAGEMENT;**38**;9/30/97
  ;
 INIT ; set up HL7 application variables
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSJXR ; DRIVER FOR COMPILED XREFS FOR FILE #55 ; 12/12/07
+PSSJXR ; DRIVER FOR COMPILED XREFS FOR FILE #55 ; 01/17/08
  ; 
  N DH,DU,DIKILL,DISET,DIKJ,DIKZ,DIKYR,DIKZA,DIK0Z,DIKZK,DIKDP,DIKM1,DIKUP,DIKUM,DV,DIIX,DIKF,DIAU,DIKNM,DIKDA,DIKLK,DIKLM,DIKY,DIXR,DIKCOND,DIKSVDA,DIKPUSH,X1,X2
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR1.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR1.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR1.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSJXR1 ; COMPILED XREF FOR FILE #55 ; 12/12/07
+PSSJXR1 ; COMPILED XREF FOR FILE #55 ; 01/17/08
  ; 
  S DIKZK=2
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR10.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR10.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR10.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSJXR10 ; COMPILED XREF FOR FILE #55.051 ; 12/12/07
+PSSJXR10 ; COMPILED XREF FOR FILE #55.051 ; 01/17/08
  ; 
  S DA(1)=0 S DA=0
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR11.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR11.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR11.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSJXR11 ; COMPILED XREF FOR FILE #55.0611 ; 12/12/07
+PSSJXR11 ; COMPILED XREF FOR FILE #55.0611 ; 01/17/08
  ; 
  S DA(1)=0 S DA=0
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR12.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR12.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR12.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSJXR12 ; COMPILED XREF FOR FILE #55.07 ; 12/12/07
+PSSJXR12 ; COMPILED XREF FOR FILE #55.07 ; 01/17/08
  ; 
  S DA(1)=0 S DA=0
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR13.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR13.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR13.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSJXR13 ; COMPILED XREF FOR FILE #55.09 ; 12/12/07
+PSSJXR13 ; COMPILED XREF FOR FILE #55.09 ; 01/17/08
  ; 
  S DA(1)=0 S DA=0
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR14.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR14.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR14.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSJXR14 ; COMPILED XREF FOR FILE #55.11 ; 12/12/07
+PSSJXR14 ; COMPILED XREF FOR FILE #55.11 ; 01/17/08
  ; 
  S DA(1)=0 S DA=0
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR15.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR15.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR15.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSJXR15 ; COMPILED XREF FOR FILE #55.1138 ; 12/12/07
+PSSJXR15 ; COMPILED XREF FOR FILE #55.1138 ; 01/17/08
  ; 
  S DA(1)=0 S DA=0
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR16.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR16.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR16.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSJXR16 ; COMPILED XREF FOR FILE #55.6114 ; 12/12/07
+PSSJXR16 ; COMPILED XREF FOR FILE #55.6114 ; 01/17/08
  ; 
  S DA(1)=0 S DA=0
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR17.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR17.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR17.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSJXR17 ; COMPILED XREF FOR FILE #55 ; 12/12/07
+PSSJXR17 ; COMPILED XREF FOR FILE #55 ; 01/17/08
  ; 
  S DIKZK=1
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR18.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR18.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR18.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSJXR18 ; COMPILED XREF FOR FILE #55.01 ; 12/12/07
+PSSJXR18 ; COMPILED XREF FOR FILE #55.01 ; 01/17/08
  ; 
  S DA(1)=DA S DA=0
@@ -63,5 +63,18 @@
  S X=$P(DIKZ(4),U,10)
  I X'="" K:X ^PS(55,"ANIV",DA(1),DA) S:'X ^PS(55,"ANIV",DA(1),DA)=""
-CR1 S DIXR=415
+CR1 S DIXR=481
+ K X
+ S DIKZ(0)=$G(^PS(55,DA(1),"IV",DA,0))
+ S X(1)=$P(DIKZ(0),U,2)
+ S X(2)=$P(DIKZ(0),U,3)
+ S X=$G(X(1))
+ I $G(X(1))]"",$G(X(2))]"" D
+ . K X1,X2 M X1=X,X2=X
+ . N DIKXARR M DIKXARR=X S DIKCOND=1
+ . S X=$$PATCH^XPDUTL("PXRM*1.5*12")
+ . S DIKCOND=$G(X) K X M X=DIKXARR
+ . Q:'DIKCOND
+ . D SPSPA^PSJXRFS(.X,.DA,"IV")
+CR2 S DIXR=493
  K X
  S DIKZ(.2)=$G(^PS(55,DA(1),"IV",DA,.2))
@@ -77,18 +90,5 @@
  . Q:'DIKCOND
  . S ^PS(55,"ACX",$E(X(1),1,30),$E(X(2),1,30),DA_"V")=""
-CR2 S DIXR=466
- K X
- S DIKZ(0)=$G(^PS(55,DA(1),"IV",DA,0))
- S X(1)=$P(DIKZ(0),U,2)
- S X(2)=$P(DIKZ(0),U,3)
- S X=$G(X(1))
- I $G(X(1))]"",$G(X(2))]"" D
- . K X1,X2 M X1=X,X2=X
- . N DIKXARR M DIKXARR=X S DIKCOND=1
- . S X=$$PATCH^XPDUTL("PXRM*1.5*12")
- . S DIKCOND=$G(X) K X M X=DIKXARR
- . Q:'DIKCOND
- . D SPSPA^PSJXRFS(.X,.DA,"IV")
-CR3 S DIXR=498
+CR3 S DIXR=494
  K X
  S DIKZ(0)=$G(^PS(55,DA(1),"IV",DA,0))
@@ -100,5 +100,5 @@
  . K X1,X2 M X1=X,X2=X
  . S ^PS(55,"AIVC",$E(X(1),1,20),$E(X(2),1,20),DA(1),DA)=""
-CR4 S DIXR=500
+CR4 S DIXR=496
  K X
  S DIKZ(0)=$G(^PS(55,DA(1),"IV",DA,0))
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR19.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR19.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR19.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSJXR19 ; COMPILED XREF FOR FILE #55.0105 ; 12/12/07
+PSSJXR19 ; COMPILED XREF FOR FILE #55.0105 ; 01/17/08
  ; 
  S DA=0
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR2.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR2.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR2.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSJXR2 ; COMPILED XREF FOR FILE #55.01 ; 12/12/07
+PSSJXR2 ; COMPILED XREF FOR FILE #55.01 ; 01/17/08
  ; 
  S DA(1)=DA S DA=0
@@ -63,21 +63,6 @@
  S X=$P(DIKZ(0),U,1)
  I X'="" K ^PS(55,DA(1),"IV","B",$E(X,1,30),DA)
-CR1 S DIXR=415
+CR1 S DIXR=481
  K X
- S DIKZ(.2)=$G(^PS(55,DA(1),"IV",DA,.2))
- S X(1)=$P(DIKZ(.2),U,8)
- S X(2)=$P(DIKZ(0),U,21)
- S X=$G(X(1))
- I $G(X(1))]"",$G(X(2))]"" D
- . K X1,X2 M X1=X,X2=X
- . S:$D(DIKIL) (X2,X2(1),X2(2))=""
- . N DIKXARR M DIKXARR=X S DIKCOND=1
- . S X=1
- . S DIKCOND=$G(X) K X M X=DIKXARR
- . Q:'DIKCOND
- . K ^PS(55,"ACX",$E(X(1),1,30),$E(X(2),1,30),DA_"V")
-CR2 S DIXR=466
- K X
- S DIKZ(0)=$G(^PS(55,DA(1),"IV",DA,0))
  S X(1)=$P(DIKZ(0),U,2)
  S X(2)=$P(DIKZ(0),U,3)
@@ -91,5 +76,20 @@
  . Q:'DIKCOND
  . D KPSPA^PSJXRFK(.X,.DA,"IV")
-CR3 S DIXR=498
+CR2 S DIXR=493
+ K X
+ S DIKZ(.2)=$G(^PS(55,DA(1),"IV",DA,.2))
+ S X(1)=$P(DIKZ(.2),U,8)
+ S DIKZ(0)=$G(^PS(55,DA(1),"IV",DA,0))
+ S X(2)=$P(DIKZ(0),U,21)
+ S X=$G(X(1))
+ I $G(X(1))]"",$G(X(2))]"" D
+ . K X1,X2 M X1=X,X2=X
+ . S:$D(DIKIL) (X2,X2(1),X2(2))=""
+ . N DIKXARR M DIKXARR=X S DIKCOND=1
+ . S X=1
+ . S DIKCOND=$G(X) K X M X=DIKXARR
+ . Q:'DIKCOND
+ . K ^PS(55,"ACX",$E(X(1),1,30),$E(X(2),1,30),DA_"V")
+CR3 S DIXR=494
  K X
  S DIKZ(0)=$G(^PS(55,DA(1),"IV",DA,0))
@@ -102,5 +102,5 @@
  . S:$D(DIKIL) (X2,X2(1),X2(2))=""
  . K ^PS(55,"AIVC",$E(X(1),1,20),$E(X(2),1,20),DA(1),DA)
-CR4 S DIXR=500
+CR4 S DIXR=496
  K X
  S DIKZ(0)=$G(^PS(55,DA(1),"IV",DA,0))
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR20.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR20.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR20.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSJXR20 ; COMPILED XREF FOR FILE #55.0108 ; 12/12/07
+PSSJXR20 ; COMPILED XREF FOR FILE #55.0108 ; 01/17/08
  ; 
  S DA=0
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR21.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR21.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR21.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSJXR21 ; COMPILED XREF FOR FILE #55.03 ; 12/12/07
+PSSJXR21 ; COMPILED XREF FOR FILE #55.03 ; 01/17/08
  ; 
  S DA=0
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR22.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR22.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR22.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSJXR22 ; COMPILED XREF FOR FILE #55.05 ; 12/12/07
+PSSJXR22 ; COMPILED XREF FOR FILE #55.05 ; 01/17/08
  ; 
  S DA=0
@@ -14,5 +14,5 @@
  S X=$P(DIKZ(0),U,10)
  I X'="" S ^PS(55,"ADCDT",$E(X,1,30),DA(1),DA)=""
-CR1 S DIXR=464
+CR1 S DIXR=479
  K X
  S X(1)=$P(DIKZ(0),U,1)
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR23.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR23.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR23.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSJXR23 ; COMPILED XREF FOR FILE #55.06 ; 12/12/07
+PSSJXR23 ; COMPILED XREF FOR FILE #55.06 ; 01/17/08
  ; 
  S DA=0
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR24.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR24.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR24.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSJXR24 ; COMPILED XREF FOR FILE #55.02 ; 12/12/07
+PSSJXR24 ; COMPILED XREF FOR FILE #55.02 ; 01/17/08
  ; 
  I X'="" D
@@ -48,18 +48,5 @@
  S X=$P(DIKZ(0),U,27)
  I X'="" I '$D(DIU(0)) D:$D(PSGAL(107)) KILL^PSGAL5:PSGAL(107)=X K PSGAL
-CR1 S DIXR=414
- K X
- S DIKZ(.2)=$G(^PS(55,DA(1),5,DA,.2))
- S X(1)=$P(DIKZ(.2),U,8)
- S X(2)=$P(DIKZ(0),U,21)
- S X=$G(X(1))
- I $G(X(1))]"",$G(X(2))]"" D
- . K X1,X2 M X1=X,X2=X
- . N DIKXARR M DIKXARR=X S DIKCOND=1
- . S X=1
- . S DIKCOND=$G(X) K X M X=DIKXARR
- . Q:'DIKCOND
- . S ^PS(55,"ACX",$E(X(1),1,30),$E(X(2),1,30),DA_"U")=""
-CR2 S DIXR=465
+CR1 S DIXR=480
  K X
  S DIKZ(2)=$G(^PS(55,DA(1),5,DA,2))
@@ -74,5 +61,19 @@
  . Q:'DIKCOND
  . D SPSPA^PSJXRFS(.X,.DA,"UD")
-CR3 S DIXR=499
+CR2 S DIXR=492
+ K X
+ S DIKZ(.2)=$G(^PS(55,DA(1),5,DA,.2))
+ S X(1)=$P(DIKZ(.2),U,8)
+ S DIKZ(0)=$G(^PS(55,DA(1),5,DA,0))
+ S X(2)=$P(DIKZ(0),U,21)
+ S X=$G(X(1))
+ I $G(X(1))]"",$G(X(2))]"" D
+ . K X1,X2 M X1=X,X2=X
+ . N DIKXARR M DIKXARR=X S DIKCOND=1
+ . S X=1
+ . S DIKCOND=$G(X) K X M X=DIKXARR
+ . Q:'DIKCOND
+ . S ^PS(55,"ACX",$E(X(1),1,30),$E(X(2),1,30),DA_"U")=""
+CR3 S DIXR=495
  K X
  S DIKZ(2)=$G(^PS(55,DA(1),5,DA,2))
@@ -84,5 +85,5 @@
  . K X1,X2 M X1=X,X2=X
  . S ^PS(55,"AUDC",$E(X(1),1,20),$E(X(2),1,20),DA(1),DA)=""
-CR4 S DIXR=501
+CR4 S DIXR=497
  K X
  S DIKZ(2)=$G(^PS(55,DA(1),5,DA,2))
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR25.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR25.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR25.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSJXR25 ; COMPILED XREF FOR FILE #55.02 ; 12/12/07
+PSSJXR25 ; COMPILED XREF FOR FILE #55.02 ; 01/17/08
  ; 
  S DA(2)=DA(1) S DA(1)=0 S DA=0
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR26.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR26.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR26.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSJXR26 ; COMPILED XREF FOR FILE #55.051 ; 12/12/07
+PSSJXR26 ; COMPILED XREF FOR FILE #55.051 ; 01/17/08
  ; 
  S DA(1)=0 S DA=0
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR27.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR27.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR27.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSJXR27 ; COMPILED XREF FOR FILE #55.0611 ; 12/12/07
+PSSJXR27 ; COMPILED XREF FOR FILE #55.0611 ; 01/17/08
  ; 
  S DA(1)=0 S DA=0
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR28.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR28.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR28.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSJXR28 ; COMPILED XREF FOR FILE #55.07 ; 12/12/07
+PSSJXR28 ; COMPILED XREF FOR FILE #55.07 ; 01/17/08
  ; 
  S DA(1)=0 S DA=0
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR29.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR29.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR29.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSJXR29 ; COMPILED XREF FOR FILE #55.09 ; 12/12/07
+PSSJXR29 ; COMPILED XREF FOR FILE #55.09 ; 01/17/08
  ; 
  S DA(1)=0 S DA=0
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR3.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR3.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR3.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSJXR3 ; COMPILED XREF FOR FILE #55.0105 ; 12/12/07
+PSSJXR3 ; COMPILED XREF FOR FILE #55.0105 ; 01/17/08
  ; 
  S DA=0
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR30.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR30.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR30.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSJXR30 ; COMPILED XREF FOR FILE #55.11 ; 12/12/07
+PSSJXR30 ; COMPILED XREF FOR FILE #55.11 ; 01/17/08
  ; 
  S DA(1)=0 S DA=0
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR31.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR31.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR31.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSJXR31 ; COMPILED XREF FOR FILE #55.1138 ; 12/12/07
+PSSJXR31 ; COMPILED XREF FOR FILE #55.1138 ; 01/17/08
  ; 
  S DA(1)=0 S DA=0
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR32.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR32.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR32.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSJXR32 ; COMPILED XREF FOR FILE #55.6114 ; 12/12/07
+PSSJXR32 ; COMPILED XREF FOR FILE #55.6114 ; 01/17/08
  ; 
  S DA(1)=0 S DA=0
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR4.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR4.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR4.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSJXR4 ; COMPILED XREF FOR FILE #55.0108 ; 12/12/07
+PSSJXR4 ; COMPILED XREF FOR FILE #55.0108 ; 01/17/08
  ; 
  S DA=0
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR5.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR5.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR5.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSJXR5 ; COMPILED XREF FOR FILE #55.03 ; 12/12/07
+PSSJXR5 ; COMPILED XREF FOR FILE #55.03 ; 01/17/08
  ; 
  S DA=0
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR6.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR6.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR6.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSJXR6 ; COMPILED XREF FOR FILE #55.05 ; 12/12/07
+PSSJXR6 ; COMPILED XREF FOR FILE #55.05 ; 01/17/08
  ; 
  S DA=0
@@ -14,5 +14,5 @@
  S X=$P(DIKZ(0),U,1)
  I X'="" K ^PS(55,DA(1),"NVA","B",$E(X,1,30),DA)
-CR1 S DIXR=464
+CR1 S DIXR=479
  K X
  S X(1)=$P(DIKZ(0),U,1)
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR7.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR7.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR7.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSJXR7 ; COMPILED XREF FOR FILE #55.06 ; 12/12/07
+PSSJXR7 ; COMPILED XREF FOR FILE #55.06 ; 01/17/08
  ; 
  S DA=0
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR8.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR8.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR8.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSJXR8 ; COMPILED XREF FOR FILE #55.06 ; 12/12/07
+PSSJXR8 ; COMPILED XREF FOR FILE #55.06 ; 01/17/08
  ; 
  S X=$P(DIKZ(6.5),U,1)
@@ -32,21 +32,6 @@
  S X=$P(DIKZ(0),U,1)
  I X'="" K ^PS(55,"ANV",DA(1),DA)
-CR1 S DIXR=414
+CR1 S DIXR=480
  K X
- S DIKZ(.2)=$G(^PS(55,DA(1),5,DA,.2))
- S X(1)=$P(DIKZ(.2),U,8)
- S X(2)=$P(DIKZ(0),U,21)
- S X=$G(X(1))
- I $G(X(1))]"",$G(X(2))]"" D
- . K X1,X2 M X1=X,X2=X
- . S:$D(DIKIL) (X2,X2(1),X2(2))=""
- . N DIKXARR M DIKXARR=X S DIKCOND=1
- . S X=1
- . S DIKCOND=$G(X) K X M X=DIKXARR
- . Q:'DIKCOND
- . K ^PS(55,"ACX",$E(X(1),1,30),$E(X(2),1,30),DA_"U")
-CR2 S DIXR=465
- K X
- S DIKZ(2)=$G(^PS(55,DA(1),5,DA,2))
  S X(1)=$P(DIKZ(2),U,2)
  S X(2)=$P(DIKZ(2),U,4)
@@ -60,5 +45,20 @@
  . Q:'DIKCOND
  . D KPSPA^PSJXRFK(.X,.DA,"UD")
-CR3 S DIXR=499
+CR2 S DIXR=492
+ K X
+ S DIKZ(.2)=$G(^PS(55,DA(1),5,DA,.2))
+ S X(1)=$P(DIKZ(.2),U,8)
+ S DIKZ(0)=$G(^PS(55,DA(1),5,DA,0))
+ S X(2)=$P(DIKZ(0),U,21)
+ S X=$G(X(1))
+ I $G(X(1))]"",$G(X(2))]"" D
+ . K X1,X2 M X1=X,X2=X
+ . S:$D(DIKIL) (X2,X2(1),X2(2))=""
+ . N DIKXARR M DIKXARR=X S DIKCOND=1
+ . S X=1
+ . S DIKCOND=$G(X) K X M X=DIKXARR
+ . Q:'DIKCOND
+ . K ^PS(55,"ACX",$E(X(1),1,30),$E(X(2),1,30),DA_"U")
+CR3 S DIXR=495
  K X
  S DIKZ(2)=$G(^PS(55,DA(1),5,DA,2))
@@ -71,5 +71,5 @@
  . S:$D(DIKIL) (X2,X2(1),X2(2))=""
  . K ^PS(55,"AUDC",$E(X(1),1,20),$E(X(2),1,20),DA(1),DA)
-CR4 S DIXR=501
+CR4 S DIXR=497
  K X
  S DIKZ(2)=$G(^PS(55,DA(1),5,DA,2))
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR9.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR9.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSJXR9.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSJXR9 ; COMPILED XREF FOR FILE #55.02 ; 12/12/07
+PSSJXR9 ; COMPILED XREF FOR FILE #55.02 ; 01/17/08
  ; 
  S DA(2)=DA(1) S DA(1)=0 S DA=0
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSMARK.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSMARK.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSMARK.m	(revision 636)
@@ -1,4 +1,4 @@
 PSSMARK ;BIR/WRT-Review single NDF matches for CMOP ; 10/27/98 13:44
- ;;1.0;PHARMACY DATA MANAGEMENT;**15,17,20,28,57,82,124**;9/30/97;Build 2
+ ;;1.0;PHARMACY DATA MANAGEMENT;**15,17,20,28,57,82**;9/30/97
  ;
  ;Reference to ^PS(59 supported by DBIA #1976
@@ -35,8 +35,5 @@
  Q
 BLD ;
- I $D(^PSDRUG(PSXUM,"I")) D  ;; <*124 RJS
- .N X,X1,X2
- .S X1=$G(^PSDRUG(PSXUM,"I")),X2=DT D ^%DTC
- .S:X<1 PSSEXP(1)="It has been inactivated."  ;; *124 RJS >
+ I $D(^PSDRUG(PSXUM,"I")) S PSSEXP(1)="It has been inactivated."
  I $D(^PSDRUG(PSXUM,2)),$P(^PSDRUG(PSXUM,2),"^",3)'["O" S PSSEXP(2)="It is not marked for outpatient pharmacy use."
 BLD5 I $P(^PSDRUG(PSXUM,0),"^",3)[1!($P(^(0),"^",3)[2) S PSSEXP(3)="It is a schedule I or schedule II controlled substance."
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSVX6.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSVX6.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSVX6.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSVX6 ; DRIVER FOR COMPILED XREFS FOR FILE #52.6 ; 03/08/06
+PSSVX6 ; DRIVER FOR COMPILED XREFS FOR FILE #52.6 ; 04/10/06
  ; 
  N DH,DU,DIKILL,DISET,DIKJ,DIKZ,DIKYR,DIKZA,DIK0Z,DIKZK,DIKDP,DIKM1,DIKUP,DIKUM,DV,DIIX,DIKF,DIAU,DIKNM,DIKDA,DIKLK,DIKLM,DIKY,DIXR,DIKCOND,DIKSVDA,DIKPUSH,X1,X2
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSVX61.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSVX61.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSVX61.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSVX61 ; COMPILED XREF FOR FILE #52.6 ; 03/08/06
+PSSVX61 ; COMPILED XREF FOR FILE #52.6 ; 04/10/06
  ; 
  S DIKZK=2
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSVX62.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSVX62.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSVX62.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSVX62 ; COMPILED XREF FOR FILE #52.61 ; 03/08/06
+PSSVX62 ; COMPILED XREF FOR FILE #52.61 ; 04/10/06
  ; 
  S DA(1)=DA S DA=0
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSVX63.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSVX63.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSVX63.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSVX63 ; COMPILED XREF FOR FILE #52.63 ; 03/08/06
+PSSVX63 ; COMPILED XREF FOR FILE #52.63 ; 04/10/06
  ; 
  S DA=0
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSVX64.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSVX64.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSVX64.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSVX64 ; COMPILED XREF FOR FILE #52.6 ; 03/08/06
+PSSVX64 ; COMPILED XREF FOR FILE #52.6 ; 04/10/06
  ; 
  S DIKZK=1
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSVX65.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSVX65.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSVX65.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSVX65 ; COMPILED XREF FOR FILE #52.61 ; 03/08/06
+PSSVX65 ; COMPILED XREF FOR FILE #52.61 ; 04/10/06
  ; 
  S DA(1)=DA S DA=0
Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSVX66.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSVX66.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSVX66.m	(revision 636)
@@ -1,3 +1,3 @@
-PSSVX66 ; COMPILED XREF FOR FILE #52.63 ; 03/08/06
+PSSVX66 ; COMPILED XREF FOR FILE #52.63 ; 04/10/06
  ; 
  S DA=0

Index: FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSDDUT2.m
===================================================================
--- FOIAVistA/trunk/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSDDUT2.m	(revision 631)
+++ FOIAVistA/tag/r/PHARMACY_DATA_MANAGEMENT-PSS/PSSDDUT2.m	(revision 636)
@@ -1,4 +1,4 @@
-PSSDDUT2 ;BIR/LDT - Pharmacy Data Management DD Utility ; 8/21/07 8:43am
- ;;1.0; PHARMACY DATA MANAGEMENT; **3,21,61,81,95,127,126**;9/30/97;Build 11
+PSSDDUT2 ;BIR/LDT - Pharmacy Data Management DD Utility ;10/30/97 9:41
+ ;;1.0; PHARMACY DATA MANAGEMENT; **3,21,61,81,95,127**;9/30/97;Build 41
  ;
  ;Reference to ^DIC(42 supported by DBIA #10039
@@ -33,33 +33,9 @@
  ;;R          RESTRICTED ITEMS
  ;;S          SUPPLY ITEMS
- ;;B          ALLOW REFILL (SCH. 3, 4, 5 ONLY)
+ ;;B          ALLOW REFILL (SCH. 3, 4, 5 NARCOTICS ONLY)
  ;;W          NOT RENEWABLE
  ;;F          NON REFILLABLE
  ;;E          ELECTRONICALLY BILLABLE
  ;;
-DEATBL ; More Help regarding DEA Codes
- K PSSHLP
- F II=1:1 Q:$P($T(TBL+II),";",3)=""  S PSSHLP(II)=$P($T(TBL+II),";",3,99)
- S PSSHLP(1,"F")="!!" D WRITE
- ;
-TBL K II Q
- ;;          DEA CODE TABLE
- ;; CODE   ALLOW RENEWS ALLOW REFILLS
- ;; 1            NO           NO
- ;; 2            NO           NO
- ;; 2A           NO           NO 
- ;; 3            YES          YES
- ;; 3A           YES          NO
- ;; 3AB          YES          YES
- ;; 4            YES          YES
- ;; 4A           YES          NO
- ;; 4AB          YES          YES
- ;; 5            YES          YES
- ;; 5A           YES          NO
- ;; 5AB          YES          YES
- ;; ADDING W TO A SCHED. 3,4,OR 5 CODE DISALLOWS RENEWS.
- ;; ADDING F TO A SCHED. 3,4,OR 5 CODE DISALLOWS REFILLS
- ;; IF A CODE IS NOT LISTED IN THE ABOVE TABLE
- ;; IT HAS NO EFFECT ON RENEW OR REFILL
 SIG ;checks SIG for RXs (Replaces SIG^PSOHELP)
  I $E(X)=" " D EN^DDIOL("Leading spaces are not allowed in the SIG! ","","$C(7),!") K X Q
@@ -108,6 +84,5 @@
 EDIT ;INPUT XFORM FOR DEA FIELD IN DRUG FILE (Replaces EDIT^PSODEA)
  I X["F",X["B" D EN^DDIOL("Inappropriate F designation!","","$C(7),!") K X Q
- ;;DEA CHANGE PSS*1*126
- I X["B",(+X<3) D EN^DDIOL("The B designation is only valid for schedule 3, 4, 5 !","","$C(7),!") K X Q
+ I X["B",(+X<3!(X'["A")) D EN^DDIOL("The B designation is only valid for schedule 3, 4, 5 narcotics !","","$C(7),!") K X Q
  I X["A"&(X["C"),+X=2!(+X=3) D EN^DDIOL("The A & C designation is not valid for schedule 2 or 3 narcotics !","","$C(7),!") K X Q
  I $E(X)=1,X[2!(X[3)!(X[4)!(X[5) D EN^DDIOL("It contains other inappropriate schedule 2-5 narcotics!","","$C(7),!") K X Q